package Strings;

use strict;
use warnings;

our (@ISA, @EXPORT);

require Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(strip stripquotes html fromdos text2html);

##########################################################################
# Strip whitespaces of string
sub strip {
  my $string = shift;
  $string =~ s/^\s+//;
  $string =~ s/\s+$//;
  
  return $string;
}

##########################################################################
# Remove surrounding double-quotes of string
# - if no quotes are found, original string is returned
# - whitespaces before or after the quotes are removed
# - whitespaced insided the quotes are reserved
sub stripquotes {
  my $string = shift;
  if ($string =~ /^\s*"(.*)"\s*$/) {
   	# remove surrounding spaces
    $string = strip($string);
    $string =~ s/^"//;
    $string =~ s/"$//;
  }
  return $string;
}

##########################################################################
# Convert special characters to be displayed in HTML
sub html {
    my $string = shift;
    $string =~ s/&/&amp/g;
    $string =~ s/</&lt/g;
    $string =~ s/>/&gt/g;
    $string =~ s/ /&nbsp/g;
    $string =~ s/-/&#8209;/g;
    
    return $string;
}

##########################################################################
# Remove end-of-line characters 
sub fromdos {
  my $line = $_[0];
  $line =~ s/\n//g;
  $line =~ s/\r//g;
  $line =~ s/        /\t/g;
  return $line;
}

##########################################################################
# Split line in line of (max) lenght lines 
#   and convert those to html code
sub text2html {
	my $text   = shift;
	my $length = shift;
	if (!$length) { $length = 10000 }
	
	my @lines = ();
	my $line  = '';
	my @words = split(/ /, $text);
	my $word  = '';
		
	if (length($text)>$length) {
		# Comment too long for one line ...
		# Break into separate lines
		foreach $word (@words) {
			if (length($line.' '.$word)<=$length) {
				$line .= ' '.$word
			} else {
				if ($line eq '') { 
					# single $word is longer as $CommentLength ...
					push @lines, html($word);
				} else {
					push @lines, html(strip($line));
					$line = $word;
				}
			}
		}
		if ($line ne '') { push @lines, html(strip($line)) }
	} else {
		push @lines, html($text);
	}

	$text = join(' ', @lines);	

	return $text;
}
